/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.changedetection.state;

import org.gradle.api.Nullable;

import java.io.File;

public interface FilesSnapshotSet {

    /**
     * Provides snapshot of a given file. null if it does not contain information about the snapshot of given input file.
     * @param file input
     * @return file snapshot for given input or null.
     */
    @Nullable FileSnapshot findSnapshot(File file);

    FilesSnapshotSet EMPTY = new FilesSnapshotSet() {
        public FileSnapshot findSnapshot(File file) {
            return null;
        }
    };
}